# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKSpatialObjectsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkSpatialObjectToImageFilterPython
else:
    import _itkSpatialObjectToImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkSpatialObjectBasePython
import itk.itkAffineTransformPython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkArrayPython
import itk.itkVariableLengthVectorPython
import itk.itkOptimizerParametersPython
import itk.ITKCommonBasePython
import itk.itkArray2DPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkSpatialObjectPropertyPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython
import itk.itkVectorContainerPython
import itk.itkContinuousIndexPython
import itk.itkImageSourcePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython

def itkSpatialObjectToImageFilterSO2IF2_New():
    return itkSpatialObjectToImageFilterSO2IF2.New()

class itkSpatialObjectToImageFilterSO2IF2(itk.itkImageSourcePython.itkImageSourceIF2):
    r"""Proxy of C++ itkSpatialObjectToImageFilterSO2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSpatialObjectToImageFilterSO2IF2_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSpatialObjectToImageFilterSO2IF2_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkSpatialObject2 const *

        SetInput(self, arg0, object)

        Parameters
        ----------
        arg0: unsigned int
        object: itkSpatialObject2 const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkSpatialObject2
        GetInput(self, idx) -> itkSpatialObject2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD2 const &

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetSpacing(self)

    def SetDirection(self, dir):
        r"""
        SetDirection(self, dir)

        Parameters
        ----------
        dir: itkMatrixD22 const &

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetDirection(self, dir)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetDirection(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> float"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetInsideValue(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> float"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetOutsideValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD2 const &

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetOrigin(self)

    def SetIndex(self, _arg):
        r"""
        SetIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetIndex(self, _arg)

    def GetIndex(self):
        r"""GetIndex(self) -> itkIndex2"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetIndex(self)

    def SetChildrenDepth(self, _arg):
        r"""
        SetChildrenDepth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetChildrenDepth(self, _arg)

    def GetChildrenDepth(self):
        r"""GetChildrenDepth(self) -> unsigned int"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetChildrenDepth(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetSize(self)

    def SetUseObjectValue(self, _arg):
        r"""
        SetUseObjectValue(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_SetUseObjectValue(self, _arg)

    def GetUseObjectValue(self):
        r"""GetUseObjectValue(self) -> bool"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_GetUseObjectValue(self)

    def UseObjectValueOn(self):
        r"""UseObjectValueOn(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_UseObjectValueOn(self)

    def UseObjectValueOff(self):
        r"""UseObjectValueOff(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_UseObjectValueOff(self)
    __swig_destroy__ = _itkSpatialObjectToImageFilterPython.delete_itkSpatialObjectToImageFilterSO2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSpatialObjectToImageFilterSO2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSpatialObjectToImageFilterSO2IF2

        Create a new object of the class itkSpatialObjectToImageFilterSO2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSpatialObjectToImageFilterSO2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSpatialObjectToImageFilterSO2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSpatialObjectToImageFilterSO2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSpatialObjectToImageFilterSO2IF2 in _itkSpatialObjectToImageFilterPython:
_itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IF2_swigregister(itkSpatialObjectToImageFilterSO2IF2)

def itkSpatialObjectToImageFilterSO2ISS2_New():
    return itkSpatialObjectToImageFilterSO2ISS2.New()

class itkSpatialObjectToImageFilterSO2ISS2(itk.itkImageSourcePython.itkImageSourceISS2):
    r"""Proxy of C++ itkSpatialObjectToImageFilterSO2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSpatialObjectToImageFilterSO2ISS2_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSpatialObjectToImageFilterSO2ISS2_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkSpatialObject2 const *

        SetInput(self, arg0, object)

        Parameters
        ----------
        arg0: unsigned int
        object: itkSpatialObject2 const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkSpatialObject2
        GetInput(self, idx) -> itkSpatialObject2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD2 const &

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetSpacing(self)

    def SetDirection(self, dir):
        r"""
        SetDirection(self, dir)

        Parameters
        ----------
        dir: itkMatrixD22 const &

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetDirection(self, dir)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetDirection(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetInsideValue(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetOutsideValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD2 const &

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetOrigin(self)

    def SetIndex(self, _arg):
        r"""
        SetIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetIndex(self, _arg)

    def GetIndex(self):
        r"""GetIndex(self) -> itkIndex2"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetIndex(self)

    def SetChildrenDepth(self, _arg):
        r"""
        SetChildrenDepth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetChildrenDepth(self, _arg)

    def GetChildrenDepth(self):
        r"""GetChildrenDepth(self) -> unsigned int"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetChildrenDepth(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetSize(self)

    def SetUseObjectValue(self, _arg):
        r"""
        SetUseObjectValue(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_SetUseObjectValue(self, _arg)

    def GetUseObjectValue(self):
        r"""GetUseObjectValue(self) -> bool"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_GetUseObjectValue(self)

    def UseObjectValueOn(self):
        r"""UseObjectValueOn(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_UseObjectValueOn(self)

    def UseObjectValueOff(self):
        r"""UseObjectValueOff(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_UseObjectValueOff(self)
    __swig_destroy__ = _itkSpatialObjectToImageFilterPython.delete_itkSpatialObjectToImageFilterSO2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSpatialObjectToImageFilterSO2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSpatialObjectToImageFilterSO2ISS2

        Create a new object of the class itkSpatialObjectToImageFilterSO2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSpatialObjectToImageFilterSO2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSpatialObjectToImageFilterSO2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSpatialObjectToImageFilterSO2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSpatialObjectToImageFilterSO2ISS2 in _itkSpatialObjectToImageFilterPython:
_itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2ISS2_swigregister(itkSpatialObjectToImageFilterSO2ISS2)

def itkSpatialObjectToImageFilterSO2IUC2_New():
    return itkSpatialObjectToImageFilterSO2IUC2.New()

class itkSpatialObjectToImageFilterSO2IUC2(itk.itkImageSourcePython.itkImageSourceIUC2):
    r"""Proxy of C++ itkSpatialObjectToImageFilterSO2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSpatialObjectToImageFilterSO2IUC2_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSpatialObjectToImageFilterSO2IUC2_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkSpatialObject2 const *

        SetInput(self, arg0, object)

        Parameters
        ----------
        arg0: unsigned int
        object: itkSpatialObject2 const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkSpatialObject2
        GetInput(self, idx) -> itkSpatialObject2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD2 const &

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetSpacing(self)

    def SetDirection(self, dir):
        r"""
        SetDirection(self, dir)

        Parameters
        ----------
        dir: itkMatrixD22 const &

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetDirection(self, dir)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetDirection(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetInsideValue(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetOutsideValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD2 const &

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetOrigin(self)

    def SetIndex(self, _arg):
        r"""
        SetIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetIndex(self, _arg)

    def GetIndex(self):
        r"""GetIndex(self) -> itkIndex2"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetIndex(self)

    def SetChildrenDepth(self, _arg):
        r"""
        SetChildrenDepth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetChildrenDepth(self, _arg)

    def GetChildrenDepth(self):
        r"""GetChildrenDepth(self) -> unsigned int"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetChildrenDepth(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetSize(self)

    def SetUseObjectValue(self, _arg):
        r"""
        SetUseObjectValue(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_SetUseObjectValue(self, _arg)

    def GetUseObjectValue(self):
        r"""GetUseObjectValue(self) -> bool"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_GetUseObjectValue(self)

    def UseObjectValueOn(self):
        r"""UseObjectValueOn(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_UseObjectValueOn(self)

    def UseObjectValueOff(self):
        r"""UseObjectValueOff(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_UseObjectValueOff(self)
    __swig_destroy__ = _itkSpatialObjectToImageFilterPython.delete_itkSpatialObjectToImageFilterSO2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSpatialObjectToImageFilterSO2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSpatialObjectToImageFilterSO2IUC2

        Create a new object of the class itkSpatialObjectToImageFilterSO2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSpatialObjectToImageFilterSO2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSpatialObjectToImageFilterSO2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSpatialObjectToImageFilterSO2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSpatialObjectToImageFilterSO2IUC2 in _itkSpatialObjectToImageFilterPython:
_itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO2IUC2_swigregister(itkSpatialObjectToImageFilterSO2IUC2)

def itkSpatialObjectToImageFilterSO3IF3_New():
    return itkSpatialObjectToImageFilterSO3IF3.New()

class itkSpatialObjectToImageFilterSO3IF3(itk.itkImageSourcePython.itkImageSourceIF3):
    r"""Proxy of C++ itkSpatialObjectToImageFilterSO3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSpatialObjectToImageFilterSO3IF3_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSpatialObjectToImageFilterSO3IF3_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkSpatialObject3 const *

        SetInput(self, arg0, object)

        Parameters
        ----------
        arg0: unsigned int
        object: itkSpatialObject3 const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkSpatialObject3
        GetInput(self, idx) -> itkSpatialObject3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD3 const &

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetSpacing(self)

    def SetDirection(self, dir):
        r"""
        SetDirection(self, dir)

        Parameters
        ----------
        dir: itkMatrixD33 const &

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetDirection(self, dir)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetDirection(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> float"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetInsideValue(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> float"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetOutsideValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD3 const &

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetOrigin(self)

    def SetIndex(self, _arg):
        r"""
        SetIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetIndex(self, _arg)

    def GetIndex(self):
        r"""GetIndex(self) -> itkIndex3"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetIndex(self)

    def SetChildrenDepth(self, _arg):
        r"""
        SetChildrenDepth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetChildrenDepth(self, _arg)

    def GetChildrenDepth(self):
        r"""GetChildrenDepth(self) -> unsigned int"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetChildrenDepth(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetSize(self)

    def SetUseObjectValue(self, _arg):
        r"""
        SetUseObjectValue(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_SetUseObjectValue(self, _arg)

    def GetUseObjectValue(self):
        r"""GetUseObjectValue(self) -> bool"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_GetUseObjectValue(self)

    def UseObjectValueOn(self):
        r"""UseObjectValueOn(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_UseObjectValueOn(self)

    def UseObjectValueOff(self):
        r"""UseObjectValueOff(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_UseObjectValueOff(self)
    __swig_destroy__ = _itkSpatialObjectToImageFilterPython.delete_itkSpatialObjectToImageFilterSO3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSpatialObjectToImageFilterSO3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSpatialObjectToImageFilterSO3IF3

        Create a new object of the class itkSpatialObjectToImageFilterSO3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSpatialObjectToImageFilterSO3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSpatialObjectToImageFilterSO3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSpatialObjectToImageFilterSO3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSpatialObjectToImageFilterSO3IF3 in _itkSpatialObjectToImageFilterPython:
_itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IF3_swigregister(itkSpatialObjectToImageFilterSO3IF3)

def itkSpatialObjectToImageFilterSO3ISS3_New():
    return itkSpatialObjectToImageFilterSO3ISS3.New()

class itkSpatialObjectToImageFilterSO3ISS3(itk.itkImageSourcePython.itkImageSourceISS3):
    r"""Proxy of C++ itkSpatialObjectToImageFilterSO3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSpatialObjectToImageFilterSO3ISS3_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSpatialObjectToImageFilterSO3ISS3_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkSpatialObject3 const *

        SetInput(self, arg0, object)

        Parameters
        ----------
        arg0: unsigned int
        object: itkSpatialObject3 const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkSpatialObject3
        GetInput(self, idx) -> itkSpatialObject3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD3 const &

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetSpacing(self)

    def SetDirection(self, dir):
        r"""
        SetDirection(self, dir)

        Parameters
        ----------
        dir: itkMatrixD33 const &

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetDirection(self, dir)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetDirection(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetInsideValue(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetOutsideValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD3 const &

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetOrigin(self)

    def SetIndex(self, _arg):
        r"""
        SetIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetIndex(self, _arg)

    def GetIndex(self):
        r"""GetIndex(self) -> itkIndex3"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetIndex(self)

    def SetChildrenDepth(self, _arg):
        r"""
        SetChildrenDepth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetChildrenDepth(self, _arg)

    def GetChildrenDepth(self):
        r"""GetChildrenDepth(self) -> unsigned int"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetChildrenDepth(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetSize(self)

    def SetUseObjectValue(self, _arg):
        r"""
        SetUseObjectValue(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_SetUseObjectValue(self, _arg)

    def GetUseObjectValue(self):
        r"""GetUseObjectValue(self) -> bool"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_GetUseObjectValue(self)

    def UseObjectValueOn(self):
        r"""UseObjectValueOn(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_UseObjectValueOn(self)

    def UseObjectValueOff(self):
        r"""UseObjectValueOff(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_UseObjectValueOff(self)
    __swig_destroy__ = _itkSpatialObjectToImageFilterPython.delete_itkSpatialObjectToImageFilterSO3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSpatialObjectToImageFilterSO3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSpatialObjectToImageFilterSO3ISS3

        Create a new object of the class itkSpatialObjectToImageFilterSO3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSpatialObjectToImageFilterSO3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSpatialObjectToImageFilterSO3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSpatialObjectToImageFilterSO3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSpatialObjectToImageFilterSO3ISS3 in _itkSpatialObjectToImageFilterPython:
_itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3ISS3_swigregister(itkSpatialObjectToImageFilterSO3ISS3)

def itkSpatialObjectToImageFilterSO3IUC3_New():
    return itkSpatialObjectToImageFilterSO3IUC3.New()

class itkSpatialObjectToImageFilterSO3IUC3(itk.itkImageSourcePython.itkImageSourceIUC3):
    r"""Proxy of C++ itkSpatialObjectToImageFilterSO3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSpatialObjectToImageFilterSO3IUC3_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSpatialObjectToImageFilterSO3IUC3_Pointer"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkSpatialObject3 const *

        SetInput(self, arg0, object)

        Parameters
        ----------
        arg0: unsigned int
        object: itkSpatialObject3 const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkSpatialObject3
        GetInput(self, idx) -> itkSpatialObject3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: itkVectorD3 const &

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetSpacing(self)

    def SetDirection(self, dir):
        r"""
        SetDirection(self, dir)

        Parameters
        ----------
        dir: itkMatrixD33 const &

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetDirection(self, dir)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetDirection(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetInsideValue(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetOutsideValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: itkPointD3 const &

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetOrigin(self)

    def SetIndex(self, _arg):
        r"""
        SetIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetIndex(self, _arg)

    def GetIndex(self):
        r"""GetIndex(self) -> itkIndex3"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetIndex(self)

    def SetChildrenDepth(self, _arg):
        r"""
        SetChildrenDepth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetChildrenDepth(self, _arg)

    def GetChildrenDepth(self):
        r"""GetChildrenDepth(self) -> unsigned int"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetChildrenDepth(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetSize(self)

    def SetUseObjectValue(self, _arg):
        r"""
        SetUseObjectValue(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_SetUseObjectValue(self, _arg)

    def GetUseObjectValue(self):
        r"""GetUseObjectValue(self) -> bool"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_GetUseObjectValue(self)

    def UseObjectValueOn(self):
        r"""UseObjectValueOn(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_UseObjectValueOn(self)

    def UseObjectValueOff(self):
        r"""UseObjectValueOff(self)"""
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_UseObjectValueOff(self)
    __swig_destroy__ = _itkSpatialObjectToImageFilterPython.delete_itkSpatialObjectToImageFilterSO3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSpatialObjectToImageFilterSO3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSpatialObjectToImageFilterSO3IUC3

        Create a new object of the class itkSpatialObjectToImageFilterSO3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSpatialObjectToImageFilterSO3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSpatialObjectToImageFilterSO3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSpatialObjectToImageFilterSO3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSpatialObjectToImageFilterSO3IUC3 in _itkSpatialObjectToImageFilterPython:
_itkSpatialObjectToImageFilterPython.itkSpatialObjectToImageFilterSO3IUC3_swigregister(itkSpatialObjectToImageFilterSO3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def spatial_object_to_image_filter(*args,  spacing: Sequence[float]=..., direction=..., inside_value: int=..., outside_value: int=..., origin: Sequence[float]=..., index: Sequence[int]=..., children_depth: int=..., size: Sequence[int]=..., use_object_value: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for SpatialObjectToImageFilter"""
    import itk

    kwarg_typehints = { 'spacing':spacing,'direction':direction,'inside_value':inside_value,'outside_value':outside_value,'origin':origin,'index':index,'children_depth':children_depth,'size':size,'use_object_value':use_object_value }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.SpatialObjectToImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def spatial_object_to_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKSpatialObjects.SpatialObjectToImageFilter
    spatial_object_to_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    spatial_object_to_image_filter.__doc__ = filter_object.__doc__



